<?php

namespace Hrm\Candidate\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Candidate\Models\Candidate;

class CandidatePolicy
{

    /**
     * Determine if the given user can view the candidate.
     *
     * @param UserPolicy $user
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function view(UserPolicy $user, Candidate $candidate)
    {
        if ($user->canDo('candidate.candidate.view') && $user->isAdmin()) {
            return true;
        }

        return $candidate->user_id == user_id() && $candidate->user_type == user_type();
    }

    /**
     * Determine if the given user can create a candidate.
     *
     * @param UserPolicy $user
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('candidate.candidate.create');
    }

    /**
     * Determine if the given user can update the given candidate.
     *
     * @param UserPolicy $user
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function update(UserPolicy $user, Candidate $candidate)
    {
        if ($user->canDo('candidate.candidate.edit') && $user->isAdmin()) {
            return true;
        }

        return $candidate->user_id == user_id() && $candidate->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given candidate.
     *
     * @param UserPolicy $user
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Candidate $candidate)
    {
        return $candidate->user_id == user_id() && $candidate->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given candidate.
     *
     * @param UserPolicy $user
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Candidate $candidate)
    {
        if ($user->canDo('candidate.candidate.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given candidate.
     *
     * @param UserPolicy $user
     * @param Candidate $candidate
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Candidate $candidate)
    {
        if ($user->canDo('candidate.candidate.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
